@@ -1,6 +1,6 @@
 package App::GitGot::Command;
 {
-  $App::GitGot::Command::VERSION = '1.09';
+  $App::GitGot::Command::VERSION = '1.10';
 }
 BEGIN {
   $App::GitGot::Command::AUTHORITY = 'cpan:GENEHACK';
@@ -14,6 +14,7 @@ use 5.010;
 use App::GitGot::Repo::Git;
 use File::Path 2.08         qw/ make_path /;
 use List::Util              qw/ max /;
+use Path::Class;
 use Try::Tiny;
 use YAML                    qw/ DumpFile LoadFile /;
 use namespace::autoclean;
@@ -455,6 +456,45 @@ sub _update {
   }
 }
 
+sub _path_is_managed {
+  my( $self , $path ) = @_;
+
+  my $dir = dir( $path );
+
+  # find repo root
+  while ( ! grep { -d and $_->basename eq '.git' } $dir->children ) {
+    die "$path doesn't seem to be in a git directory\n" if $dir eq $dir->parent;
+    $dir = $dir->parent;
+  }
+
+  my $max_len = $self->max_length_of_an_active_repo_label;
+
+  for my $repo ( $self->active_repos ) {
+    next unless $repo->path eq $dir->absolute;
+
+    my $repo_remote = ( $repo->repo and -d $repo->path ) ? $repo->repo
+      : ( $repo->repo )    ? $repo->repo . ' (Not checked out)'
+      : ( -d $repo->path ) ? 'NO REMOTE'
+      : 'ERROR: No remote and no repo?!';
+
+    printf "%3d) ", $repo->number;
+
+    if ( $self->quiet ) { say $repo->label }
+    else {
+      printf "%-${max_len}s  %-4s  %s\n",
+        $repo->label, $repo->type, $repo_remote;
+      if ( $self->verbose ) {
+        printf "    tags: %s\n" , $repo->tags if $repo->tags;
+      }
+    }
+
+    return 1;
+  }
+
+  say "repository not in Got list";
+  return;
+}
+
 # override this in commands that shouldn't use IO::Page -- i.e., ones that
 # need to do incremental output
 sub _use_io_page { 1 }
@@ -466,13 +506,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 App::GitGot::Command - Base class for App::GitGot commands
 
 =head1 VERSION
 
-version 1.09
+version 1.10
 
 =head1 METHODS
 
