@@ -1,6 +1,6 @@
 package App::GitGot::Command::mux;
 {
-  $App::GitGot::Command::mux::VERSION = '1.09';
+  $App::GitGot::Command::mux::VERSION = '1.10';
 }
 BEGIN {
   $App::GitGot::Command::mux::AUTHORITY = 'cpan:GENEHACK';
@@ -11,6 +11,14 @@ use Mouse;
 extends 'App::GitGot::Command';
 use 5.010;
 
+has session => (
+    traits        => [qw(Getopt)],
+    isa           => 'Bool',
+    is            => 'ro',
+    cmd_aliases   => 's',
+    documentation => 'use tmux-sessions',
+);
+
 sub command_names { qw/ mux tmux / }
 
 sub _execute {
@@ -23,17 +31,30 @@ sub _execute {
 
   my( $repo ) = $self->active_repos;
 
+  my $target = $self->session ? 'session' : 'window';
+
   # is it already opened?
   my %windows = reverse map { /^(\d+):::(\S+)/ }
-    split "\n", `tmux list-windows -F"#I:::#W"`;
+    split "\n", `tmux list-$target -F"#I:::#W"`;
 
   if( my $window = $windows{$repo->name} ) {
-      exec 'tmux', 'select-window', '-t' => $window;
+    if ($self->session) {
+        exec 'tmux', 'switch-client', '-t' => $window;
+    } else {
+        exec 'tmux', 'select-window', '-t' => $window;
+    }
   }
 
   chdir $repo->path;
 
-  exec 'tmux', 'new-window', '-n', $repo->name;
+  if ($self->session) {
+    delete local $ENV{TMUX};
+    system 'tmux', 'new-session', '-d', '-s', $repo->name;
+    exec 'tmux', 'switch-client', '-t' => $repo->name;
+  } else {
+    exec 'tmux', 'new-window', '-n', $repo->name;
+  }
+
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -43,13 +64,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 App::GitGot::Command::mux - open a tmux window for a selected project
 
 =head1 VERSION
 
-version 1.09
+version 1.10
 
 =head1 AUTHOR
 
